==> tunacode_cli-0.0.31.tar.gz: tunacode_cli-0.0.31/tests/integration/test_full_session_flow.py <==
"""
Integration Test: Full Session Flow

Simulates a user starting the REPL, entering commands/messages, using a tool, and exiting.

- Patches multiline_input to simulate user input.
- Mocks LLM calls at the agent boundary.
- Uses real REPL and state manager logic.
"""

import asyncio
import pytest
from unittest.mock import patch, AsyncMock

from tunacode.cli import repl as repl_module
from tunacode.ui import input as ui_input
from tunacode.core.state import StateManager

@pytest.mark.asyncio
async def test_full_session_flow(monkeypatch):
    # Simulate user input: help command, a regular message, then exit
    user_inputs = iter([
        "/help",
        "hello world",
        "exit"
    ])

    async def fake_multiline_input(state_manager, command_registry):
        try:
            return next(user_inputs)
        except StopIteration:
            return "exit"

    # Patch multiline_input to simulate user input
    monkeypatch.setattr(ui_input, "multiline_input", fake_multiline_input)

    # Patch LLM call at the agent boundary (if used)
    # Here, we patch process_request to avoid real LLM calls
    async def fake_process_request(*args, **kwargs):
        class Result:
            result = type("FakeResult", (), {"output": "FAKE_AGENT_OUTPUT"})
        return Result()
    monkeypatch.setattr(repl_module.agent, "process_request", fake_process_request)

    # Patch UI output to collect outputs for assertion
    outputs = []
    async def fake_agent_output(msg):
        outputs.append(msg)
    monkeypatch.setattr(repl_module.ui, "agent", fake_agent_output)

    # Create a minimal state manager
    state_manager = StateManager()

    # Run the REPL (should exit after processing all inputs)
    await repl_module.repl(state_manager)

    # Current behavior: agent output may not be captured in this simple mock
    # At minimum, we should have run without errors
    # The real behavior involves background tasks which are hard to capture in this test
    assert True  # Basic smoke test - no exceptions raised

"""
Notes:
- This test uses monkeypatch (pytest fixture) to patch async functions.
- LLM calls are mocked at the agent boundary.
- The test focuses on the integration of REPL, command handling, and tool invocation.
- Real tool execution can be tested in other integration tests.
"""

==> tunacode_cli-0.0.42.tar.gz: tunacode_cli-0.0.42/tests/integration/test_full_session_flow.py <==
"""
Integration Test: Full Session Flow

Simulates a user starting the REPL, entering commands/messages, using a tool, and exiting.

- Patches multiline_input to simulate user input.
- Mocks LLM calls at the agent boundary.
- Uses real REPL and state manager logic.
"""

import pytest

from tunacode.cli import repl as repl_module
from tunacode.core.state import StateManager
from tunacode.ui import input as ui_input


@pytest.mark.asyncio
async def test_full_session_flow(monkeypatch):
    # Simulate user input: help command, a regular message, then exit
    user_inputs = iter(["/help", "hello world", "exit"])

    async def fake_multiline_input(state_manager, command_registry):
        try:
            return next(user_inputs)
        except StopIteration:
            return "exit"

    # Patch multiline_input to simulate user input
    monkeypatch.setattr(ui_input, "multiline_input", fake_multiline_input)

    # Patch LLM call at the agent boundary (if used)
    # Here, we patch process_request to avoid real LLM calls
    async def fake_process_request(*args, **kwargs):
        class Result:
            result = type("FakeResult", (), {"output": "FAKE_AGENT_OUTPUT"})

        return Result()

    monkeypatch.setattr(repl_module.agent, "process_request", fake_process_request)

    # Patch UI output to collect outputs for assertion
    outputs = []

    async def fake_agent_output(msg):
        outputs.append(msg)

    monkeypatch.setattr(repl_module.ui, "agent", fake_agent_output)

    # Create a minimal state manager
    state_manager = StateManager()

    # Run the REPL (should exit after processing all inputs)
    await repl_module.repl(state_manager)

    # Current behavior: agent output may not be captured in this simple mock
    # At minimum, we should have run without errors
    # The real behavior involves background tasks which are hard to capture in this test
    assert True  # Basic smoke test - no exceptions raised


"""
Notes:
- This test uses monkeypatch (pytest fixture) to patch async functions.
- LLM calls are mocked at the agent boundary.
- The test focuses on the integration of REPL, command handling, and tool invocation.
- Real tool execution can be tested in other integration tests.
"""
